<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Atomic
 */

if ( ! function_exists( 'atomic_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 */
function atomic_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'atomic' ); ?></h1>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'atomic' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'atomic' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'atomic_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 */
function atomic_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'atomic' ); ?></h1>
		<div class="nav-links">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', _x( '<span class="meta-nav">&larr;</span>&nbsp;%title', 'Previous post link', 'atomic' ) );
				next_post_link(     '<div class="nav-next">%link</div>',     _x( '%title&nbsp;<span class="meta-nav">&rarr;</span>', 'Next post link',     'atomic' ) );
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'atomic_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function atomic_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	echo $time_string;
}

function atomic_comment_count() {
	if ( ! post_password_required() ) {
		echo '<span class="comments-link">';	
		comments_popup_link( __('Leave a comment', 'atomic'), __( '1 Comment', 'atomic' ), __( '% Comments', 'atomic' ), __('Comments Off', 'atomic'));
		echo '</span>';
	}
}
endif;

if ( ! function_exists( 'atomic_display_categories' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function atomic_display_categories() {
	// Hide category and tag text for pages.
	if ( 'post' == get_post_type() ) {
		$categories_list = get_the_category_list( __( ' ', 'atomic' ) );
		if ( $categories_list && atomic_categorized_blog() ) {
			printf( '<span class="cat-links">%1$s</span>', $categories_list );
		}
	}
}

function atomic_display_edit() {
	if ( 'post' == get_post_type() ) {
		edit_post_link( 'Edit', '<span class="edit-link">', '</span>' );
	}
}

function atomic_display_tags() {
	if ( 'post' == get_post_type() ) {
		$tags_list = get_the_tag_list( '', __( ' ', 'atomic' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">Tagged: %1$s</span>', $tags_list );
		}
	}
}
endif;

if ( ! function_exists( 'atomic_comments_number' ) ) :
/**
 * Prints HTML with meta information for the comments.
 */
function atomic_comments_number() {

	if ( ! post_password_required() ) {
		echo '<span class="comments-link">';	
		comments_popup_link( __('Leave a comment', 'atomic'), __( '1 Comment', 'atomic' ), __( '% Comments', 'atomic' ), __('comments-link', 'atomic'), __('Comments Off', 'atomic'));
		echo '</span>';
	}
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function atomic_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'atomic_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'atomic_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so atomic_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so atomic_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in atomic_categorized_blog.
 */
function atomic_category_transient_flusher() {
	delete_transient( 'atomic_categories' );
}
add_action( 'edit_category', 'atomic_category_transient_flusher' );
add_action( 'save_post',     'atomic_category_transient_flusher' );